@@ -30,3 +30,11 @@ impl UserRepository for UserRepositoryImpl {
         Ok(result)
     }
 }
+
+impl UserRepositoryImpl { 
+    pub fn new(user_factory: Arc<dyn UserFactory + Send + Sync>, 
+               hashed_password_factory: Arc<dyn HashedPasswordFactory + Send + Sync>) 
+    -> Self { 
+        UserRepositoryImpl{user_factory: user_factory, hashed_password_factory: hashed_password_factory}    
+    }
+}
